# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/devices/generic/CpuStateCollection.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.devices.generic.CpuState_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/devices/generic/CpuStateCollection.proto',
  package='rst.devices.generic',
  serialized_pb='\n,rst/devices/generic/CpuStateCollection.proto\x12\x13rst.devices.generic\x1a\"rst/devices/generic/CpuState.proto\"D\n\x12\x43puStateCollection\x12.\n\x07\x65lement\x18\x01 \x03(\x0b\x32\x1d.rst.devices.generic.CpuStateB\x18\x42\x16\x43puStateCollectionType')




_CPUSTATECOLLECTION = _descriptor.Descriptor(
  name='CpuStateCollection',
  full_name='rst.devices.generic.CpuStateCollection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='element', full_name='rst.devices.generic.CpuStateCollection.element', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=105,
  serialized_end=173,
)

_CPUSTATECOLLECTION.fields_by_name['element'].message_type = rst.devices.generic.CpuState_pb2._CPUSTATE
DESCRIPTOR.message_types_by_name['CpuStateCollection'] = _CPUSTATECOLLECTION

class CpuStateCollection(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _CPUSTATECOLLECTION

  # @@protoc_insertion_point(class_scope:rst.devices.generic.CpuStateCollection)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\026CpuStateCollectionType')
# @@protoc_insertion_point(module_scope)
