# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/geometry/Cylinder3DFloat.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.geometry.Pose_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/geometry/Cylinder3DFloat.proto',
  package='rst.geometry',
  serialized_pb='\n\"rst/geometry/Cylinder3DFloat.proto\x12\x0crst.geometry\x1a\x17rst/geometry/Pose.proto\"]\n\x0f\x43ylinder3DFloat\x12*\n\x0etransformation\x18\x01 \x02(\x0b\x32\x12.rst.geometry.Pose\x12\x0e\n\x06radius\x18\x02 \x02(\x02\x12\x0e\n\x06height\x18\x03 \x02(\x02\x42\x15\x42\x13\x43ylinder3DFloatType')




_CYLINDER3DFLOAT = _descriptor.Descriptor(
  name='Cylinder3DFloat',
  full_name='rst.geometry.Cylinder3DFloat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='transformation', full_name='rst.geometry.Cylinder3DFloat.transformation', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='radius', full_name='rst.geometry.Cylinder3DFloat.radius', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='height', full_name='rst.geometry.Cylinder3DFloat.height', index=2,
      number=3, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=77,
  serialized_end=170,
)

_CYLINDER3DFLOAT.fields_by_name['transformation'].message_type = rst.geometry.Pose_pb2._POSE
DESCRIPTOR.message_types_by_name['Cylinder3DFloat'] = _CYLINDER3DFLOAT

class Cylinder3DFloat(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _CYLINDER3DFLOAT

  # @@protoc_insertion_point(class_scope:rst.geometry.Cylinder3DFloat)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\023Cylinder3DFloatType')
# @@protoc_insertion_point(module_scope)
